@@ -16,7 +16,7 @@
 import github.GithubObject
 
 
-class AuthorizationApplication(github.GithubObject.GithubObject):
+class AuthorizationApplication(github.GithubObject.CompletableGithubObject):
     """
     This class represents AuthorizationApplications as returned for example by http://developer.github.com/v3/todo
     """
