@@ -19,7 +19,7 @@ import github.Commit
 import github.File
 
 
-class Comparison(github.GithubObject.GithubObject):
+class Comparison(github.GithubObject.CompletableGithubObject):
     """
     This class represents Comparisons as returned for example by http://developer.github.com/v3/todo
     """
