@@ -16,7 +16,7 @@
 import github.GithubObject
 
 
-class GistFile(github.GithubObject.BasicGithubObject):
+class GistFile(github.GithubObject.NonCompletableGithubObject):
     """
     This class represents GistFiles as returned for example by http://developer.github.com/v3/todo
     """
