@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -15,7 +15,15 @@
 
 
 class InputFileContent(object):
+    """
+    """
+
     def __init__(self, content):
+        """
+        :param content: string
+        """
+
+        assert isinstance(content, (str, unicode)), content
         self.__content = content
 
     @property
