@@ -16,7 +16,7 @@
 import github.GithubObject
 
 
-class Permissions(github.GithubObject.BasicGithubObject):
+class Permissions(github.GithubObject.NonCompletableGithubObject):
     """
     This class represents Permissionss as returned for example by http://developer.github.com/v3/todo
     """
