@@ -18,7 +18,7 @@ import github.GithubObject
 import github.NamedUser
 
 
-class PullRequestComment(github.GithubObject.GithubObject):
+class PullRequestComment(github.GithubObject.CompletableGithubObject):
     """
     This class represents PullRequestComments as returned for example by http://developer.github.com/v3/todo
     """
